Index: trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java	(revision 5907)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/Addresses.java	(revision 5908)
@@ -85,8 +85,13 @@
     public void visit(Node n) {
         List<Relation> associatedStreets = getAndCheckAssociatedStreets(n);
         // Find house number without proper location (neither addr:street, associatedStreet or addr:place)
         if (n.hasKey(ADDR_HOUSE_NUMBER) && !n.hasKey(ADDR_STREET) && !n.hasKey(ADDR_PLACE)) {
             for (Relation r : associatedStreets) {
                 if (r.hasTag("type", ASSOCIATED_STREET)) {
+                    return;
+                }
+            }
+            for (Way w : OsmPrimitive.getFilteredList(n.getReferrers(), Way.class)) {
+                if (w.hasKey(ADDR_INTERPOLATION) && w.hasKey(ADDR_STREET)) {
                     return;
                 }
@@ -85,8 +85,13 @@
     public void visit(Node n) {
         List<Relation> associatedStreets = getAndCheckAssociatedStreets(n);
-        // Find house number without proper location (neither addr:street, associatedStreet or addr:place)
+        // Find house number without proper location (neither addr:street, associatedStreet, addr:place or addr:interpolation)
         if (n.hasKey(ADDR_HOUSE_NUMBER) && !n.hasKey(ADDR_STREET) && !n.hasKey(ADDR_PLACE)) {
             for (Relation r : associatedStreets) {
